pub enum InsertOrigin {
Local,
Sync {
from: PeerIdBytes,
remote_content_status: ContentStatus,
},
}Expand description
Whether an entry was inserted locally or by a remote peer.
Variants
Local
The entry was inserted locally.
Sync
The entry was received from the remote node identified by PeerIdBytes.
Fields

from: PeerIdBytesThe peer from which we received this entry.

remote_content_status: ContentStatusWhether the peer claims to have the content blob for this entry.