Record

Struct Record 

pub struct Record { /* private fields */ }
The data part of an entry in a Replica.

Implementations

Source

impl Record

pub fn new(hash: Hash, len: u64, timestamp: u64) -> Self

Create a new record.

pub fn empty(timestamp: u64) -> Self

Create a tombstone record (empty content)

pub fn empty_current() -> Self

Create a tombstone record with the timestamp set to now.

pub fn is_empty(&self) -> bool

Return true if the entry is empty.

pub fn new_current(hash: Hash, len: u64) -> Self

Create a new Record with the timestamp set to now.

pub fn content_len(&self) -> u64

Get the length of the data addressed by this record’s content hash.

pub fn content_hash(&self) -> Hash

Get the Hash of the content data of this record.

pub fn timestamp(&self) -> u64

Get the timestamp of this record.